aboutsummaryrefslogtreecommitdiffstats
path: root/ui/app
diff options
context:
space:
mode:
authorHsuan Lee <hsuan@cobinhood.com>2018-12-10 18:57:44 +0800
committerHsuan Lee <hsuan@cobinhood.com>2018-12-10 19:02:47 +0800
commitc0ede3738ebc693d035943ecd226f991eb9149c1 (patch)
treeb318f6afda470984c198cea0248bb354f14a1bd4 /ui/app
parent283c23101dd614d50f4ab9c866727d13b131a3dd (diff)
downloaddexon-wallet-c0ede3738ebc693d035943ecd226f991eb9149c1.tar.gz
dexon-wallet-c0ede3738ebc693d035943ecd226f991eb9149c1.tar.zst
dexon-wallet-c0ede3738ebc693d035943ecd226f991eb9149c1.zip
Fix rebase errors
Diffstat (limited to 'ui/app')
-rw-r--r--ui/app/components/currency-input/tests/currency-input.container.test.js6
-rw-r--r--ui/app/components/dropdowns/network-dropdown.js2
-rw-r--r--ui/app/components/eth-balance.js2
-rw-r--r--ui/app/components/gas-customization/gas-modal-page-container/tests/gas-modal-page-container-container.test.js4
-rw-r--r--ui/app/components/send/send.selectors.js6
-rw-r--r--ui/app/components/user-preferenced-currency-display/user-preferenced-currency-display.container.js2
-rw-r--r--ui/app/components/wallet-view.js9
-rw-r--r--ui/app/reducers.js2
-rw-r--r--ui/app/selectors/custom-gas.js8
9 files changed, 15 insertions, 26 deletions
diff --git a/ui/app/components/currency-input/tests/currency-input.container.test.js b/ui/app/components/currency-input/tests/currency-input.container.test.js
index ce66f386..feb5a8eb 100644
--- a/ui/app/components/currency-input/tests/currency-input.container.test.js
+++ b/ui/app/components/currency-input/tests/currency-input.container.test.js
@@ -52,12 +52,8 @@ describe('CurrencyInput container', () => {
assert.deepEqual(mergeProps(mockStateProps, mockDispatchProps, {}), {
conversionRate: 280.45,
currentCurrency: 'usd',
-<<<<<<< HEAD
- nativeCurrency: 'ETH',
- suffix: 'ETH',
-=======
+ nativeCurrency: 'DEX',
suffix: 'DEX',
->>>>>>> Update Dexon wording
})
})
})
diff --git a/ui/app/components/dropdowns/network-dropdown.js b/ui/app/components/dropdowns/network-dropdown.js
index d8298963..7f52db98 100644
--- a/ui/app/components/dropdowns/network-dropdown.js
+++ b/ui/app/components/dropdowns/network-dropdown.js
@@ -26,7 +26,7 @@ function mapStateToProps (state) {
provider: state.dekusan.provider,
frequentRpcListDetail: state.dekusan.frequentRpcListDetail || [],
networkDropdownOpen: state.appState.networkDropdownOpen,
- network: state.metamask.network,
+ network: state.dekusan.network,
}
}
diff --git a/ui/app/components/eth-balance.js b/ui/app/components/eth-balance.js
index 2f6395a2..218dc3b9 100644
--- a/ui/app/components/eth-balance.js
+++ b/ui/app/components/eth-balance.js
@@ -12,7 +12,7 @@ const FiatValue = require('./fiat-value.js')
module.exports = connect(mapStateToProps)(EthBalanceComponent)
function mapStateToProps (state) {
return {
- ticker: state.metamask.ticker,
+ ticker: state.dekusan.ticker,
}
}
diff --git a/ui/app/components/gas-customization/gas-modal-page-container/tests/gas-modal-page-container-container.test.js b/ui/app/components/gas-customization/gas-modal-page-container/tests/gas-modal-page-container-container.test.js
index 51283286..72a03eca 100644
--- a/ui/app/components/gas-customization/gas-modal-page-container/tests/gas-modal-page-container-container.test.js
+++ b/ui/app/components/gas-customization/gas-modal-page-container/tests/gas-modal-page-container-container.test.js
@@ -45,7 +45,7 @@ proxyquire('../gas-modal-page-container.container.js', {
'../../../ducks/confirm-transaction.duck': confirmTransactionActionSpies,
'../../../ducks/send.duck': sendActionSpies,
'../../../selectors.js': {
- getCurrentEthBalance: (state) => state.metamask.balance || '0x0',
+ getCurrentEthBalance: (state) => state.dekusan.balance || '0x0',
},
})
@@ -138,7 +138,7 @@ describe('gas-modal-page-container container', () => {
{ mockState: baseMockState, expectedResult: baseExpectedResult, mockOwnProps: baseMockOwnProps },
{
mockState: Object.assign({}, baseMockState, {
- metamask: { ...baseMockState.metamask, balance: '0xfffffffffffffffffffff' },
+ dekusan: { ...baseMockState.dekusan, balance: '0xfffffffffffffffffffff' },
}),
expectedResult: Object.assign({}, baseExpectedResult, { insufficientBalance: false }),
mockOwnProps: baseMockOwnProps,
diff --git a/ui/app/components/user-preferenced-currency-display/user-preferenced-currency-display.container.js b/ui/app/components/user-preferenced-currency-display/user-preferenced-currency-display.container.js
index af60aa1d..f5aae92c 100644
--- a/ui/app/components/user-preferenced-currency-display/user-preferenced-currency-display.container.js
+++ b/ui/app/components/user-preferenced-currency-display/user-preferenced-currency-display.container.js
@@ -8,7 +8,7 @@ const mapStateToProps = (state, ownProps) => {
return {
useNativeCurrencyAsPrimaryCurrency,
- nativeCurrency: state.metamask.nativeCurrency,
+ nativeCurrency: state.dekusan.nativeCurrency,
}
}
diff --git a/ui/app/components/wallet-view.js b/ui/app/components/wallet-view.js
index 404d733e..4e329060 100644
--- a/ui/app/components/wallet-view.js
+++ b/ui/app/components/wallet-view.js
@@ -37,17 +37,10 @@ function mapStateToProps (state) {
return {
network: state.dekusan.network,
sidebarOpen: state.appState.sidebar.isOpen,
-<<<<<<< HEAD
- identities: state.metamask.identities,
- accounts: selectors.getMetaMaskAccounts(state),
- tokens: state.metamask.tokens,
- keyrings: state.metamask.keyrings,
-=======
identities: state.dekusan.identities,
- accounts: state.dekusan.accounts,
+ accounts: selectors.getMetaMaskAccounts(state),
tokens: state.dekusan.tokens,
keyrings: state.dekusan.keyrings,
->>>>>>> Fix UI bugs
selectedAddress: selectors.getSelectedAddress(state),
selectedAccount: selectors.getSelectedAccount(state),
selectedTokenAddress: state.dekusan.selectedTokenAddress,
diff --git a/ui/app/reducers.js b/ui/app/reducers.js
index 57865c33..0b596493 100644
--- a/ui/app/reducers.js
+++ b/ui/app/reducers.js
@@ -62,7 +62,7 @@ window.getCleanAppState = function () {
state.version = global.platform.getVersion()
state.browser = window.navigator.userAgent
// ensure seedWords are not included
- if (state.metamask) delete state.metamask.seedWords
+ if (state.dekusan) delete state.dekusan.seedWords
if (state.appState.currentView) delete state.appState.currentView.seedWords
return state
}
diff --git a/ui/app/selectors/custom-gas.js b/ui/app/selectors/custom-gas.js
index 59f240f9..e98df53f 100644
--- a/ui/app/selectors/custom-gas.js
+++ b/ui/app/selectors/custom-gas.js
@@ -189,8 +189,8 @@ function getRenderableBasicEstimateData (state) {
if (getBasicGasEstimateLoadingStatus(state)) {
return []
}
- const gasLimit = state.metamask.send.gasLimit || getCustomGasLimit(state)
- const conversionRate = state.metamask.conversionRate
+ const gasLimit = state.dekusan.send.gasLimit || getCustomGasLimit(state)
+ const conversionRate = state.dekusan.conversionRate
const currentCurrency = getCurrentCurrency(state)
const {
gas: {
@@ -234,8 +234,8 @@ function getRenderableEstimateDataForSmallButtonsFromGWEI (state) {
if (getBasicGasEstimateLoadingStatus(state)) {
return []
}
- const gasLimit = state.metamask.send.gasLimit || getCustomGasLimit(state)
- const conversionRate = state.metamask.conversionRate
+ const gasLimit = state.dekusan.send.gasLimit || getCustomGasLimit(state)
+ const conversionRate = state.dekusan.conversionRate
const currentCurrency = getCurrentCurrency(state)
const {
gas: {
diff --git a/ui/app/components/send/send.selectors.js b/ui/app/components/send/send.selectors.js
index 175ada9b..f6638c45 100644
--- a/ui/app/components/send/send.selectors.js
+++ b/ui/app/components/send/send.selectors.js
@@ -76,9 +76,9 @@ function accountsWithSendEtherInfoSelector (state) {
// const autoAddAccountsThreshold = 2
// const autoAddTokensThreshold = 1
// const numberOfTransactions = state.metamask.selectedAddressTxList.length
// const numberOfAccounts = Object.keys(getMetaMaskAccounts(state)).length
// const numberOfTokensAdded = state.metamask.tokens.length
// const userPassesThreshold = (numberOfTransactions > autoAddTransactionThreshold) &&
// (numberOfAccounts > autoAddAccountsThreshold) &&
@@ -118,7 +118,7 @@ function getCurrentCurrency (state) {
}
function getNativeCurrency (state) {
- return state.metamask.nativeCurrency
+ return state.dekusan.nativeCurrency
}
function getCurrentNetwork (state) {
@@ -76,9 +76,9 @@ function accountsWithSendEtherInfoSelector (state) {
// const autoAddAccountsThreshold = 2
// const autoAddTokensThreshold = 1
-// const numberOfTransactions = state.metamask.selectedAddressTxList.length
+// const numberOfTransactions = state.dekusan.selectedAddressTxList.length
// const numberOfAccounts = Object.keys(getMetaMaskAccounts(state)).length
@@ -76,9 +76,9 @@ function accountsWithSendEtherInfoSelector (state) {
// const numberOfAccounts = Object.keys(getMetaMaskAccounts(state)).length
-// const numberOfTokensAdded = state.metamask.tokens.length
+// const numberOfTokensAdded = state.dekusan.tokens.length
// const userPassesThreshold = (numberOfTransactions > autoAddTransactionThreshold) &&
// (numberOfAccounts > autoAddAccountsThreshold) &&